summaryrefslogtreecommitdiffstats
path: root/core/dive.h
diff options
context:
space:
mode:
Diffstat (limited to 'core/dive.h')
-rw-r--r--core/dive.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/core/dive.h b/core/dive.h
index d40e53043..03d6fc2df 100644
--- a/core/dive.h
+++ b/core/dive.h
@@ -758,15 +758,17 @@ extern void average_max_depth(struct diveplan *dive, int *avg_depth, int *max_de
#ifdef __cplusplus
}
/* Make pointers to dive, dive_trip and dive_table "Qt metatypes" so that they can
* be passed through QVariants and through QML.
* Note: we have to use the typedef "dive_table_t" instead of "struct dive_table",
* because MOC removes the "struct", but dive_table is already the name of a global
* variable, leading to compilation errors. Likewise for "struct trip_table". */
Q_DECLARE_METATYPE(struct dive *);
Q_DECLARE_METATYPE(struct dive_trip *);
Q_DECLARE_METATYPE(dive_table_t *);
Q_DECLARE_METATYPE(trip_table_t *);
+Q_DECLARE_METATYPE(dive_site_table_t *);
#endif
@@ -758,15 +758,17 @@ extern void average_max_depth(struct diveplan *dive, int *avg_depth, int *max_de
#ifdef __cplusplus
}
-/* Make pointers to dive, dive_trip and dive_table "Qt metatypes" so that they can
- * be passed through QVariants and through QML.
+/* Make pointers to dive, dive_trip, dive_table, trip_table and dive_site_table
+ * "Qt metatypes" so that they can be passed through QVariants and through QML.
* Note: we have to use the typedef "dive_table_t" instead of "struct dive_table",
* because MOC removes the "struct", but dive_table is already the name of a global
@@ -758,15 +758,17 @@ extern void average_max_depth(struct diveplan *dive, int *avg_depth, int *max_de
* Note: we have to use the typedef "dive_table_t" instead of "struct dive_table",
* because MOC removes the "struct", but dive_table is already the name of a global
- * variable, leading to compilation errors. Likewise for "struct trip_table". */
+ * variable, leading to compilation errors. Likewise for "struct trip_table" and
+ * "struct dive_site_table". */
Q_DECLARE_METATYPE(struct dive *);
Q_DECLARE_METATYPE(struct dive_trip *);